## $Id: test_export.py 12342 2014-12-30 10:19:47Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Test the product exporter.
"""
import os
import grok
import datetime
from cStringIO import StringIO
from zope.component import queryUtility, getUtility
from zope.event import notify
from zope.interface.verify import verifyObject, verifyClass
from waeup.ikoba.interfaces import (
    ICSVExporter, IExtFileStore, IFileStoreNameChooser)
from waeup.ikoba.products.export import ProductExporter
from waeup.ikoba.products.product import Product
from waeup.ikoba.products.tests.test_batching import ProductImportExportSetup
from waeup.ikoba.testing import FunctionalLayer


class ProductExporterTest(ProductImportExportSetup):

    layer = FunctionalLayer

    def setUp(self):
        super(ProductExporterTest, self).setUp()
        self.setup_for_export()
        return

    def test_ifaces(self):
        # make sure we fullfill interface contracts
        obj = ProductExporter()
        verifyObject(ICSVExporter, obj)
        verifyClass(ICSVExporter,ProductExporter)
        return

    def test_get_as_utility(self):
        # we can get an product exporter as utility
        result = queryUtility(ICSVExporter, name="products")
        self.assertTrue(result is not None)
        return

    def test_export(self):
        # we can really export a product
        exporter = ProductExporter()
        exporter.export([self.product], self.outfile)
        result = open(self.outfile, 'rb').read()
        self.assertTrue(
            'contract_category,contract_title,options,'
            'product_id,title,users_with_local_roles\r\n'
            'license,,"[(u\'Base Fee\', u\'800.6\', u\'USD\')]",LIC,Unnamed,'
            '"[{\'user_name\': u\'john\', \'local_role\': '
            'u\'johnsrole\'}]"\r\n'
            in result
            )
        return

    def test_export_all(self):
        # we can really export all products
        exporter = ProductExporter()
        exporter.export_all(self.app, self.outfile)
        result = open(self.outfile, 'rb').read()
        self.assertTrue(
            'contract_category,contract_title,options,'
            'product_id,title,users_with_local_roles\r\n'
            'license,,"[(u\'Base Fee\', u\'800.6\', u\'USD\')]",LIC,Unnamed,'
            '"[{\'user_name\': u\'john\', \'local_role\': '
            'u\'johnsrole\'}]"\r\n'
            in result
            )
        return
